/*
 * Copyright (C) 2016 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.syndesis.connector.rest.swagger.auth.basic;

import java.nio.charset.StandardCharsets;
import java.util.Base64;

import io.syndesis.connector.rest.swagger.Configuration;
import io.syndesis.connector.rest.swagger.auth.SetAuthorizationHeader;
import io.syndesis.integration.component.proxy.ComponentProxyComponent;
import io.syndesis.integration.component.proxy.Processors;

public final class Basic {

    private Basic() {
        // utility class
    }

    public static void setup(final ComponentProxyComponent component, final Configuration configuration) {
        final String usernameAndPassword = configuration.stringOption("username") + ":" + configuration.stringOption("password");

        final String usernameAndPasswordEncoded = Base64.getEncoder()
            .encodeToString(usernameAndPassword.getBytes(StandardCharsets.UTF_8));

        final String authorizationHeaderValue = "Basic " + usernameAndPasswordEncoded;

        Processors.addBeforeProducer(component, new SetAuthorizationHeader(authorizationHeaderValue));
    }
}
